# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
### Changed

## [0.1.0] - 2019-06-15
### Added
- First release on PyPI.

[Unreleased]: https://github.com/cmeister2/leia/compare/v0.1.0...HEAD
[0.1.0]: https://github.com/cmeister2/leia/tree/v0.1.0
